#
# spec file for package kasts
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  released
Name:           kasts
Version:        23.08.4
Release:        1.1
Summary:        Kirigami-based podcast player
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/kasts
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  extra-cmake-modules
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5KirigamiAddons)
BuildRequires:  cmake(KF5NetworkManagerQt)
BuildRequires:  cmake(KF5Syndication)
BuildRequires:  cmake(KF5ThreadWeaver)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Keychain)
BuildRequires:  cmake(Qt5Multimedia)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(taglib)
Requires:       kirigami-addons
Requires:       kirigami2

%description
Kasts is a convergent podcast application.
Its main features are:

- Episode management through play queue
- Sync playback positions with other clients through gpodder.net or
  gpodder-nextcloud
- Variable playback speed
- Search for podcasts
- Full system integration: e.g. inhibit system suspend while listening

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build

%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --all-name

%files
%license LICENSES/*
%dir %{_kf5_qmldir}/org
%dir %{_kf5_qmldir}/org/kde
%{_kf5_applicationsdir}/org.kde.kasts.desktop
%{_kf5_appstreamdir}/org.kde.kasts.appdata.xml
%{_kf5_bindir}/kasts
%{_kf5_iconsdir}/hicolor/scalable/actions/media-playback-cloud.svg
%{_kf5_iconsdir}/hicolor/scalable/apps/kasts-tray-*.svg
%{_kf5_iconsdir}/hicolor/scalable/apps/kasts.svg
%{_kf5_libdir}/libKMediaSession.so
%{_kf5_libdir}/libKastsSolidExtras.so
%{_kf5_qmldir}/org/kde/kasts/
%{_kf5_qmldir}/org/kde/kmediasession/

%files lang -f %{name}.lang

%changelog
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: Store rejected. Try just the plug.
  * Add CI template for building APKs on invent
  * snapcraft: Use new mpris plug for dbus.
  * snapcraft: Fix dbus name. Add alsa conf to layouts and add plug. Add missing dev and runtime packages.
  * Fix streaming button showing up instead of download button (kde#476144)
  * Disable failing qt6 tests on release/23.08 branch
  * Remove network connectivity check
  * snapcraft: add qml and plugin import path to env. Add network-manager plug.
  * Add snapcraft.yaml to reuse.
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Bump KF minimum version to 5.105.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Implement backend to allow Feed list sort and search (kde#471012)
  * Implement sorting for queue and episode lists (kde#466855)
  * Use Entry title to set downloaded file name (kde#457848)
  * Fix segfault when trying to remove a non-subscribed podcast (kde#471107)
  * Make grace time configurable for marking episodes as played (kde#468687)
  * Also update fullscreen image if chapter image in HeaderBar changes (kde#470194)
  * Load custom icons through fallbackSearchPaths (kde#469567)
  * Add implementation for favorites (kde#459886)
  * Make Kasts use the system proxy settings (kde#467490)
  * Fix bug with empty feed causing nullptr dereference (kde#467394)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Fix mMedia nullptr dereference in VLC backend metadata call
  * More safeguards for getFeed and getEntry calls
  * Fix segfault when trying to remove a non-subscribed podcast (kde#471107)
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * [KMediaSession] Only send MRPIS2 positionChanged signal on seek
  * Also update fullscreen image if chapter image in HeaderBar changes (kde#470194)
  * Load custom icons through fallbackSearchPaths (kde#469567)
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Sun Mar 19 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Thu Jun 10 2021 Andrés B.S. <andresbs@opensuse.org>
- New package: Kasts
